Membership Manager Goals
========================

Empower many users to collaborate on content production
-------------------------------------------------------

* **XXX** :doc:`AddMemberToUserFolder`

Delegate responsibilities to site members
-------------------------------------------

* **XXX** :doc:`ChangeMemberInformation`

Ensure that only appropriate users have access to the site
------------------------------------------------------------

* **XXX** :doc:`BrowseMemberRoster`

* **XXX** :doc:`RemoveMemberFromSite`

